"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveImportDeps = void 0;
const typescript_1 = __importDefault(require("typescript"));
const utils_1 = require("./utils");
function resolveImportDeps(sourceFile, importStore, fnNode) {
    // Iterate through all nodes in this function.
    const resolveNodeDeps = (node) => {
        let dep;
        if (typescript_1.default.isTypeNode(node)) {
            dep = resolveTypeNode(sourceFile, node, importStore);
        }
        else if (typescript_1.default.isNewExpression(node)) {
            dep = resolveNewExpression(sourceFile, node, importStore);
        }
        else if (typescript_1.default.isPropertyAccessExpression(node)) {
            dep = resolvePropertyAccessExpression(sourceFile, node, importStore);
        }
        const deps = [];
        if (dep) {
            deps.push(dep);
        }
        node.forEachChild((node) => {
            deps.push(...resolveNodeDeps(node));
        });
        return deps;
    };
    let deps = resolveNodeDeps(fnNode);
    // remove duplicate
    deps = deps.filter((obj1, obj2, arr) => arr.findIndex((val) => val.name === obj1.name) === obj2);
    return deps;
}
exports.resolveImportDeps = resolveImportDeps;
// If this node is a TypeNode and it is not a Promise, return the discovery.
function resolveTypeNode(sourceFile, node, importStore) {
    const typeName = node.getText(sourceFile);
    if (typeName.startsWith("Promise")) {
        return;
    }
    // If the type format is 'ns.type', search for the first part.
    const elemName = typeName.split(".")[0];
    if ((0, utils_1.isPrimitive)(elemName)) {
        return;
    }
    const elem = importStore.searchElement(elemName);
    if (elem == undefined) {
        throw new Error(`Cannot find the type from import elements: ${typeName}.`);
    }
    return elem;
}
// Process for new expression, such as `new Cls()`.
function resolveNewExpression(sourceFile, node, importStore) {
    const typeName = node.expression.getText(sourceFile);
    // Will be processed as PropertyAccessExpression
    if (typeName.indexOf(".") !== -1) {
        return;
    }
    return importStore.searchElement(typeName);
}
// Process for property access expression, such as:
//   1. `pkg.access()`
//   2. `pkg.prop`
//   3. `obj.access()`
//   4. `obj.prop`
function resolvePropertyAccessExpression(sourceFile, node, importStore) {
    // Handle formats that package property access, such as 'pkg.access', but ignore object property access.
    const callerName = node.expression.getText(sourceFile);
    const elemName = callerName.split(".")[0];
    return importStore.searchElement(elemName);
}
//# sourceMappingURL=dep-resolve.js.map