"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = __importDefault(require("typescript"));
const vitest_1 = require("vitest");
const utils_1 = require("./utils");
const imports_1 = require("./imports");
const dep_resolve_1 = require("./dep-resolve");
function testOnce(code, importStatNum, expectDepNum) {
    const sourceFile = (0, utils_1.genInlineSourceFile)(code);
    // Parse the import statements, and build the import store
    const importStore = new imports_1.ImportStore();
    let elemCount = 0;
    sourceFile.forEachChild((node) => {
        if (!typescript_1.default.isImportDeclaration(node)) {
            return;
        }
        const importElems = (0, imports_1.extractImportElements)(sourceFile, node);
        importStore.update(importElems);
        elemCount += importElems.length;
    });
    (0, vitest_1.expect)(elemCount).toBe(importStatNum);
    // Resolve the dependencies
    const depImportElems = (0, dep_resolve_1.resolveImportDeps)(sourceFile, importStore, sourceFile);
    (0, vitest_1.expect)(depImportElems).toHaveLength(expectDepNum);
}
vitest_1.describe.concurrent("named import cases", async () => {
    const importStat = `import { foo } from "lib";`;
    const cases = [
        "foo.access();",
        "foo.prop;",
        "new foo();",
        "new foo.Cls();",
        "const obj: foo = new foo();",
        "const obj: foo.Cls = new foo.Cls();",
        "(a: number): Promise<foo> => { }",
        "(a: number): Promise<foo.Cls> => { }",
    ];
    for (const kacse of cases) {
        const code = importStat + kacse;
        vitest_1.test.concurrent(kacse, async () => testOnce(code, 1, 1));
    }
});
vitest_1.describe.concurrent("namespace import cases", async () => {
    const importStat = `import foo from "lib";`;
    const cases = [
        "foo.access();",
        "foo.prop;",
        "new foo();",
        "new foo.Cls();",
        "const obj: foo = new foo();",
        "const obj: foo.Cls = new foo.Cls();",
        "(a: number): Promise<foo> => { }",
        "(a: number): Promise<foo.Cls> => { }",
    ];
    for (const kacse of cases) {
        const code = importStat + kacse;
        vitest_1.test.concurrent(kacse, async () => testOnce(code, 1, 1));
    }
});
//# sourceMappingURL=dep-resolve.test.js.map