"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.genInlineSourceFile = exports.isPrimitive = void 0;
const typescript_1 = __importDefault(require("typescript"));
const vitest_1 = require("vitest");
function isPrimitive(val) {
    const primitiveTypes = [
        "string",
        "number",
        "boolean",
        "undefined",
        "symbol",
        "bigint",
        "void",
        "any",
        "unknown",
    ];
    return primitiveTypes.indexOf(val) !== -1;
}
exports.isPrimitive = isPrimitive;
// For testing purposes, the task is to generate a TypeScript `ts.SourceFile` from an inline code.
function genInlineSourceFile(sourceCode) {
    const fileName = "inline.ts";
    const host = {
        getCompilationSettings: () => ({
            target: typescript_1.default.ScriptTarget.ES2022,
            module: typescript_1.default.ModuleKind.CommonJS,
        }),
        getCurrentDirectory: () => process.cwd(),
        getDefaultLibFileName: (options) => typescript_1.default.getDefaultLibFilePath(options),
        getScriptFileNames: () => [fileName],
        getScriptVersion: () => "0",
        getScriptSnapshot: (name) => name === fileName ? typescript_1.default.ScriptSnapshot.fromString(sourceCode) : undefined,
        readFile: () => undefined,
        fileExists: () => true,
    };
    const service = typescript_1.default.createLanguageService(host);
    const program = service.getProgram();
    (0, vitest_1.expect)(program).toBeDefined();
    const sourceFile = program.getSourceFile(fileName);
    (0, vitest_1.expect)(sourceFile).toBeDefined();
    return sourceFile;
}
exports.genInlineSourceFile = genInlineSourceFile;
//# sourceMappingURL=utils.js.map